@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2017 Tony DiCola for Adafruit Industries
 #
-# Copyright (c) 2017 Tony DiCola for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_mpl3115a2`
 ====================================================
@@ -44,7 +27,6 @@ __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MPL3115A2.git"
 
 
-# pylint: disable=bad-whitespace
 # Internal constants:
 _MPL3115A2_ADDRESS = const(0x60)
 _MPL3115A2_REGISTER_STATUS = const(0x00)
@@ -95,7 +77,6 @@ _MPL3115A2_CTRL_REG1_OS64 = const(0x30)
 _MPL3115A2_CTRL_REG1_OS128 = const(0x38)
 
 _MPL3115A2_REGISTER_STARTCONVERSION = const(0x12)
-# pylint: enable=bad-whitespace
 
 
 class MPL3115A2:
@@ -231,8 +212,7 @@ class MPL3115A2:
 
     @property
     def temperature(self):
-        """Read the temperature as measured by the sensor in degrees Celsius.
-        """
+        """Read the temperature as measured by the sensor in degrees Celsius."""
         # Poll status for TDR to be set.
         while (
             self._read_u8(_MPL3115A2_REGISTER_STATUS) & _MPL3115A2_REGISTER_STATUS_TDR
